@@ -62,6 +62,7 @@ GtkWidget *CheckMenuItemBrowseHiddenDirMainMenu;
 #define AM_UNDO_HISTORY             "Undo"
 #define AM_REDO_HISTORY             "Redo"
 #define AM_SAVE                     "SaveFile"
+#define AM_SAVE_FORCED              "SaveFileForced"
 #define AM_SELECT_ALL_FILES         "SelAll"
 #define AM_UNSELECT_ALL_FILES       "UnselAll"
 #define AM_INVERT_SELECTION         "SelInv"
@@ -77,7 +78,7 @@ GtkWidget *CheckMenuItemBrowseHiddenDirMainMenu;
 #define AM_RELOAD_DIRECTORY         "ReloadDir"
 #define AM_TREE_OR_ARTISTALBUM_VIEW "ViewMode"
 #define AM_BROWSE_DIRECTORY_WITH    "BrowseDir"
-#define AM_BROWSE_FILE_WITH         "Open"
+#define AM_OPEN_FILE_WITH           "OpenFile"
 #define AM_OPEN_OPTIONS_WINDOW      "Preferences"
 #define AM_SCANNER_FILL_TAG         "FillTag"
 #define AM_SCANNER_RENAME_FILE      "RenameFile"
@@ -91,6 +92,11 @@ GtkWidget *CheckMenuItemBrowseHiddenDirMainMenu;
 #define AM_OPEN_ABOUT_WINDOW        "About"
 #define AM_QUIT                     "Quit"
 
+#define AM_ARTIST_RUN_AUDIO_PLAYER  "ArtistRunAudio"
+#define AM_ARTIST_OPEN_FILE_WITH    "ArtistOpenFile"
+#define AM_ALBUM_RUN_AUDIO_PLAYER   "AlbumRunAudio"
+#define AM_ALBUM_OPEN_FILE_WITH     "AlbumOpenFile"
+
 #define AM_STOP                     "Stop"
 #define AM_VIEWMODE_TOGGLE          "ViewModeToggle"
 
