@@ -346,7 +346,7 @@ const gchar *get_locale (void)
 
 
 /*
- * convert_string :
+ * convert_string : (don't use with UTF-16 strings)
  *  - display_error : if TRUE, may return an escaped string and display an error 
  *                    message (if conversion fails).
  */
@@ -393,11 +393,14 @@ gchar *convert_string_1 (const gchar *string, gssize length, const gchar *from_c
         // Patch from Alexey Illarionov:
         //    g_convert returns null-terminated string only with one \0 at the
         // end. It can cause some garbage at the end of a string for UTF-16. 
-        // The second \0 should be set manually. 
+        // The second \0 should be set manually.
         output = g_realloc(output, bytes_written + 2);
         if (output != NULL)
             output[bytes_written] = output[bytes_written + 1] = 0;
     }
+    
+    //g_print("from %s => len: %d, string: '%s'\n     (%x %x %x %x %x %x %x %x)\n",from_codeset,length,string,string[0],string[1],string[2],string[3],string[4],string[5],string[6],string[7]);
+    //g_print("to   %s => len: %d, output: '%s'\n     (%x %x %x %x %x %x %x %x)\n\n",to_codeset,bytes_written+2,output,output[0],output[1],output[2],output[3],output[4],output[5],output[6],output[7]);
 
     return output;
 }
@@ -611,7 +614,7 @@ gchar *filename_from_display (const gchar *string)
     {
         // Conversion KO!
         gchar *escaped_str = g_strescape(string, NULL);
-        g_warning(_("The UTF-8 string '%s' couldn't be converted into filename encoding (%s)\n."),
+        g_warning(_("The UTF-8 string '%s' couldn't be converted into filename encoding (%s)\n"),
                     escaped_str, error && error->message ? error->message : _("Invalid UTF-8"));
         g_clear_error(&error);
 
@@ -619,7 +622,7 @@ gchar *filename_from_display (const gchar *string)
     }
 
 #ifdef WIN32
-    ET_Win32_Path_Replace_Backslashes(ret);
+    //ET_Win32_Path_Replace_Backslashes(ret);
 #endif
 
     return ret; // We need to catch errors (e.g. temp=NULL) in the real code
