@@ -176,11 +176,12 @@ gint Action_Redo_Selected_File          (void);
 void Action_Undo_All_Files              (void);
 void Action_Redo_All_Files              (void);
 void Action_Save_Selected_Files         (void);
+void Action_Force_Saving_Selected_Files (void);
 void Action_Undo_From_History_List      (void);
 void Action_Redo_From_History_List      (void);
 void Action_Delete_Selected_Files       (void);
-gint Save_All_Files_With_Answer         (void);
-gint Save_Selected_Files_With_Answer    (void);
+gint Save_All_Files_With_Answer         (gboolean force_saving_files);
+gint Save_Selected_Files_With_Answer    (gboolean force_saving_files);
 
 void Action_Main_Stop_Button_Pressed    (void);
 void Action_Select_Browser_Style        (void);
