@@ -68,6 +68,9 @@ ID3_C_EXPORT size_t ID3Field_GetUNICODE_1 (const ID3Field *field, unicode_t *buf
 
 gboolean Id3tag_Check_If_File_Is_Corrupted (gchar *filename);
 
+gboolean Id3tag_Check_If_Id3lib_Is_Bugged (void);
+
+
 
 /*************
  * Functions *
@@ -112,8 +115,6 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     if (tmp[0] != 'I' || tmp[1] != 'D' || tmp[2] != '3' || tmp[3] >= 0xFF) // ID3v2 tag skipeer $49 44 33 yy yy xx zz zz zz zz [zz size]
     {
         // ID3v2 tag not found!
-        if (WRITE_ID3V2_TAG)
-            FileTag->saved = FALSE;
         has_id3v2_tag = FALSE;
     }
     // 2) ID3v1 tag
@@ -126,13 +127,18 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     if (tmp[0] != 'T' || tmp[1] != 'A' || tmp[2] != 'G')
     {
         // ID3v1 tag not found!
-        if (WRITE_ID3V1_TAG)
-            FileTag->saved = FALSE;
         has_id3v1_tag = FALSE;
     }
-    
     fclose(file); // We close it cause id3lib opens/closes file itself
 
+    /* We mark the file as unsaved (in color red in file list), if the tags 
+     * version found doesn't match with the settings to force to save the tag 
+     * (but only if there are data to save!) */
+    if (WRITE_ID3V2_TAG && !has_id3v2_tag && has_id3v1_tag) // Save ID3v2 if there is data in ID3v1 tag
+        FileTag->saved = FALSE;
+    if (WRITE_ID3V1_TAG && !has_id3v1_tag && has_id3v2_tag) // Save ID3v1 if there is data in ID3v2 tag
+        FileTag->saved = FALSE;
+    
     /* This is a protection against a bug in id3lib that generate an infinite
      * loop with corrupted MP3 files (files containing only zeroes) */
     if (Id3tag_Check_If_File_Is_Corrupted(filename))
@@ -396,7 +402,7 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         // Picture description
         pic->description = Id3tag_Get_Field(id3_frame, ID3FN_DESCRIPTION);
             
-        //g_print("Image format : %s\n",Id3tag_Get_Field(ID3FN_IMAGEFORMAT));
+        //g_print("Image format : '%s'\n",Id3tag_Get_Field(id3_frame, ID3FN_IMAGEFORMAT));
     }
 
 
@@ -491,8 +497,6 @@ gboolean Id3tag_Write_File_Tag (ET_File *ETFile)
     gchar    *temp;
     FILE     *file;
     ID3Tag   *id3_tag = NULL;
-    //ID3_TextEnc encoding_used = ID3TE_NONE;
-    //gboolean unicode_used = FALSE;
     ID3_Err   error_strip_id3v1  = ID3E_NoError;
     ID3_Err   error_strip_id3v2  = ID3E_NoError;
     ID3_Err   error_update_id3v1 = ID3E_NoError;
@@ -514,6 +518,8 @@ gboolean Id3tag_Write_File_Tag (ET_File *ETFile)
     gboolean has_encoded_by  = FALSE;
     gboolean has_picture     = FALSE;
     gboolean has_song_len    = FALSE;
+    static gboolean flag_first_check = TRUE;
+    static gboolean flag_id3lib_bugged = TRUE;
 
     ID3Frame *id3_frame;
     ID3Field *id3_field;
@@ -521,6 +527,16 @@ gboolean Id3tag_Write_File_Tag (ET_File *ETFile)
     gchar *string1;
     Picture *pic;
 
+
+    // When writing the first MP3 file, we check if the version of id3lib of the 
+    // system doesn't contain a bug when writting Unicode tags
+    if (flag_first_check 
+    && (USE_ID3_ISO_8859_1_THEN_UNICODE_CHARACTER_SET || USE_ID3_UNICODE_CHARACTER_SET) )
+    {
+        flag_first_check = FALSE;
+        flag_id3lib_bugged = Id3tag_Check_If_Id3lib_Is_Bugged();
+    }
+
     if (!ETFile || !ETFile->FileTag)
         return FALSE;
 
@@ -781,7 +797,7 @@ gboolean Id3tag_Write_File_Tag (ET_File *ETFile)
         id3_frame = ID3Frame_NewID(ID3FID_PICTURE);
         ID3Tag_AttachFrame(id3_tag,id3_frame);
 
-        switch(Picture_Format(pic))
+        switch (Picture_Format(pic))
         {
             case PICTURE_FORMAT_JPEG:
                 if ((id3_field = ID3Frame_GetField(id3_frame,ID3FN_MIMETYPE)))
@@ -878,6 +894,48 @@ gboolean Id3tag_Write_File_Tag (ET_File *ETFile)
             {
                 g_print(_("Error while updating ID3v2 tag of '%s' (%s)\n"),basename_utf8,Id3tag_Get_Error_Message(error_update_id3v2));
                 error++;
+            }else
+            {
+                /* See known problem on the top : [ 1016290 ] Unicode16 writing bug.
+                 * When we write the tag in Unicode, we try to check if it was correctly
+                 * written. So to test it : we read again the tag, and then compare 
+                 * with the previous one. We check up to find an error (as only some
+                 * characters are affected).
+                 * If the patch to id3lib was applied to fix the problem (tested 
+                 * by Id3tag_Check_If_Id3lib_Is_Bugged) we didn't make the following
+                 * test => OK */
+                if (flag_id3lib_bugged 
+                && (USE_ID3_ISO_8859_1_THEN_UNICODE_CHARACTER_SET || USE_ID3_UNICODE_CHARACTER_SET) )
+                {
+                    File_Tag  *FileTag_tmp = ET_File_Tag_Item_New();
+                    if (Id3tag_Read_File_Tag(filename,FileTag_tmp) == TRUE
+                    &&  ET_Detect_Changes_Of_File_Tag(FileTag,FileTag_tmp) == TRUE)
+                    {
+                        GtkWidget *msgbox = NULL;
+                        gchar *msg;
+                        gchar *filename_utf8 = filename_to_display(filename);
+
+                        msg = g_strdup_printf(_("You have tried to save this tag to Unicode "
+                            "but it was detected that your version of id3lib is bugged.\n"
+                            "If you reload this file, some characters in the tag may be not "
+                            "displayed correctly...\nPlease, apply to id3lib the patch "
+                            "src/id3lib/patch_id3lib_3.8.3_UTF16_writing_bug.diff\n"
+                            "available in EasyTAG package sources.\n"
+                            "Note that this message will appear only one time.\n\n"
+                            "File : %s"),filename_utf8);
+                        g_free(filename_utf8);
+                        //g_print(msg);
+                        
+                        msgbox = msg_box_new (_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
+                        g_free(msg);
+                        msg_box_hide_check_button(MSG_BOX(msgbox));
+                        msg_box_run(MSG_BOX(msgbox));
+                        gtk_widget_destroy(msgbox);
+                        flag_id3lib_bugged = FALSE; // To display the message only one time
+                    }
+                    ET_Free_File_Tag_Item(FileTag_tmp);
+                }
+
             }
         }else
         {
@@ -1160,7 +1218,7 @@ gchar *Id3tag_Get_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid)
         // Data of the field must be a TEXT (ID3FTY_TEXTSTRING)
         if (ID3Field_GetType(id3_field) != ID3FTY_TEXTSTRING)
         {
-            g_print("Id3tag_Get_Field() must be used only for fields containing text.\n");
+            g_warning("Id3tag_Get_Field() must be used only for fields containing text.\n");
             return NULL;
         }
 
@@ -1307,6 +1365,12 @@ gchar *Id3tag_Get_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid)
  * ISO-8859-1 encoding or UTF-16.
  *
  * Return the encoding used as if UTF-16 was used, we musn't write the ID3v1 tag.
+ *
+ * Known problem with id3lib
+ * - [ 1016290 ] Unicode16 writing bug
+ *               http://sourceforge.net/tracker/index.php?func=detail&aid=1016290&group_id=979&atid=300979
+ *               For example with Latin-1 characters (like éöäüß) not saved correctly
+ *               in Unicode, due to id3lib (for "é" it will write "E9 FF" instead of "EF 00")
  */
 /*
  * OLD NOTE : PROBLEM with ID3LIB
@@ -1470,23 +1534,25 @@ ID3_TextEnc Id3tag_Set_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid
 
             case ID3TE_UTF16:
             //case ID3TE_UTF16BE:
+
+                /* See known problem on the top : [ 1016290 ] Unicode16 writing bug */
                 // Write into UTF-16
                 string_converted = convert_string_1(string, strlen(string), "UTF-8",
                                                     "UTF-16BE", FALSE);
-    
+
                 // id3lib (3.8.3 at least) always takes big-endian input for Unicode
                 // fields, even if the field is set little-endian.
                 ID3Field_SetEncoding(id3_field,ID3TE_UTF16);
                 ID3Field_SetUNICODE(id3_field,(const unicode_t*)string_converted);
                 g_free(string_converted);
-                
+
                 id3_field_encoding = ID3Frame_GetField(id3_frame,ID3FN_TEXTENC);
                 if (id3_field_encoding)
                     ID3Field_SetINT(id3_field_encoding,ID3TE_UTF16);
-                
+
                 return ID3TE_UTF16;
                 break;
-            
+
             case 9999:
                 //string_converted = convert_string(string,"UTF-8",ID3_FILE_WRITING_CHARACTER_SET,TRUE);
                 string_converted = Id3tag_Rules_For_ISO_Fields(string,"UTF-8",ID3_FILE_WRITING_CHARACTER_SET);
@@ -1700,6 +1766,89 @@ gboolean Id3tag_Check_If_File_Is_Corrupted (gchar *filename)
     return result;
 }
 
+
+/*
+ * Function to detect if id3lib isn't bugged when writting to Unicode
+ * Returns TRUE if bugged, else FALSE
+ */
+gboolean Id3tag_Check_If_Id3lib_Is_Bugged (void)
+{
+    FILE *file;
+    unsigned char tmp[16] = {0xFF, 0xFB, 0x00, 0x00, 0x00, 0x00, 
+                             0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+                             0x00, 0x00, 0x00, 0x00};
+    ID3Tag *id3_tag = NULL;
+    gchar *filename;
+    gchar *result = NULL;
+    ID3Frame *id3_frame;
+    gboolean use_iso, use_iso_then_unicode, use_unicode;
+
+
+    if (!HOME_VARIABLE)
+        return FALSE;
+        
+    // Create a temporary file
+    filename = g_strconcat(HOME_VARIABLE,
+                           HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!=G_DIR_SEPARATOR?G_DIR_SEPARATOR_S:"",
+                           ".easytag"G_DIR_SEPARATOR_S"test_easytag.mp3",
+                           NULL);
+    if ( (file=fopen(filename,"w+"))==NULL )
+    {
+        gchar *filename_utf8 = filename_to_display(filename);
+        g_print(_("ERROR while opening file: '%s' (%s).\n\a"),filename_utf8,g_strerror(errno));
+        g_free(filename_utf8);
+        return FALSE;
+    }
+    // Set data in the file
+    fwrite(&tmp,16,1,file);
+    fclose(file);
+
+    // Save state of switches as we must force to Unicode before writting
+    use_iso              = USE_ID3_ISO_8859_1_CHARACTER_SET;
+    use_iso_then_unicode = USE_ID3_ISO_8859_1_THEN_UNICODE_CHARACTER_SET;
+    use_unicode          = USE_ID3_UNICODE_CHARACTER_SET;
+    USE_ID3_ISO_8859_1_CHARACTER_SET              = FALSE;
+    USE_ID3_ISO_8859_1_THEN_UNICODE_CHARACTER_SET = FALSE;
+    USE_ID3_UNICODE_CHARACTER_SET                 = TRUE;
+
+    id3_tag = ID3Tag_New();
+    ID3Tag_Link_1(id3_tag,filename);
+
+    // Create a new 'title' field for testing
+    id3_frame = ID3Frame_NewID(ID3FID_TITLE);
+    ID3Tag_AttachFrame(id3_tag,id3_frame);
+    Id3tag_Set_Field(id3_frame, ID3FN_TEXT, "é"); // This latin-1 character is written in Unicode as 'E9 FF' instead of 'E9 00' if bugged
+
+    // Update the tag
+    ID3Tag_UpdateByTagType(id3_tag,ID3TT_ID3V2);
+    ID3Tag_Delete(id3_tag);
+
+    USE_ID3_ISO_8859_1_CHARACTER_SET              = use_iso;
+    USE_ID3_ISO_8859_1_THEN_UNICODE_CHARACTER_SET = use_iso_then_unicode;
+    USE_ID3_UNICODE_CHARACTER_SET                 = use_unicode;
+
+
+    id3_tag = ID3Tag_New();
+    ID3Tag_Link_1(id3_tag,filename);
+    // Read the written field
+    if ( (id3_frame = ID3Tag_FindFrameWithID(id3_tag,ID3FID_TITLE)) )
+    {
+        result = Id3tag_Get_Field(id3_frame,ID3FN_TEXT);
+    }
+
+    ID3Tag_Delete(id3_tag);
+    remove(filename);
+
+    // Same string found? if yes => not bugged
+    if ( result && strcmp(result,"é")!=0 )
+    {
+        return TRUE;
+    }
+
+    return FALSE;
+}
+
+
 #endif /* ENABLE_MP3 */
 
 
