@@ -79,7 +79,7 @@ void Load_Genres_List_To_UI (void);
 void Load_Track_List_To_UI  (void);
 void Init_Character_Translation_Table (void);
 void Init_Custom_Icons (void);
-gboolean Check_If_Executable_Exists (const gchar *program);
+gchar *Check_If_Executable_Exists (const gchar *program);
 
 // Mouse cursor
 void Init_Mouse_Cursor    (void);
@@ -107,6 +107,9 @@ gulong Get_File_Size (gchar *filename);
 void Strip_String (gchar *string);
 gint Combo_Alphabetic_Sort (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer data);
 
+void File_Selection_Window_For_File      (GtkWidget *entry);
+void File_Selection_Window_For_Directory (GtkWidget *entry);
+
 // Playlist window
 void Open_Write_Playlist_Window          (void);
 void Write_Playlist_Window_Apply_Changes (void);
