@@ -33,6 +33,9 @@
 #include "charset.h"
 #include "libmpg123/mpg123.h"
 
+//#include <id3.h>
+//#include "id3lib/id3_bugfix.h"
+
 
 
 /****************
@@ -53,6 +56,7 @@ gchar *layer_names[3] =
 static gchar* channel_mode_name(int mode);
 
 
+
 /*************
  * Functions *
  *************/
@@ -78,27 +82,18 @@ static gchar* channel_mode_name(int mode)
  */
 gboolean Mpeg_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
 {
+#if (1)
     FILE *file;
     gulong filesize;
 
-/***
-    const gchar *emphasis[4];
-    const gchar *bool_label[2];
-
-    emphasis[0] = _("None");
-    emphasis[1] = _("50/15 ms");
-    emphasis[2] = "";
-    emphasis[3] = _("CCIT J.17");
-    bool_label[0] = _("No");
-    bool_label[1] = _("Yes");
-***/
 
     if (!filename || !ETFileInfo)
         return FALSE;
 
     /* Get size of file */
-    filesize = Get_File_Size(filename);
-    ETFileInfo->size      = filesize;
+    filesize         = Get_File_Size(filename);
+    ETFileInfo->size = filesize;
+
 
     /*
      * This part was taken from XMMS
@@ -176,8 +171,7 @@ gboolean Mpeg_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
                 num_frames = xing_header.frames;
                 ETFileInfo->bitrate = (gint) ((xing_header.bytes * 8) / (tpf * xing_header.frames * 1000));
                 //g_print("Bitrate: Variable,\navg. bitrate: %d kb/s\n",ETFileInfo->bitrate);
-            }
-            else
+            } else
             {
                 num_frames = ((ftell(file) - pos - (id3_found ? 128 : 0)) / mpg123_compute_bpf(&frm)) + 1;
                 ETFileInfo->bitrate = tabsel_123[frm.lsf][frm.lay - 1][frm.bitrate_index];
@@ -206,6 +200,127 @@ gboolean Mpeg_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
         return FALSE;
     }
 
+#else
+    // Needs to uncomment some #include at the beginning
+
+    /*
+     * With id3lib, the header frame couldn't be read if the file contains an ID3v2 tag with an APIC frame
+     */
+    gulong filesize;
+    ID3Tag *id3_tag = NULL;    /* Tag defined by the id3lib */
+    const Mp3_Headerinfo* headerInfo = NULL;
+
+
+    if (!filename || !ETFileInfo)
+        return FALSE;
+
+    /* Get size of file */
+    filesize         = Get_File_Size(filename);
+    ETFileInfo->size = filesize;
+
+    /* Get data from tag */
+    if ( (id3_tag = ID3Tag_New()) == NULL )
+        return FALSE;
+
+    /* Link the file to the tag (uses ID3TT_ID3V2 to get header if APIC is present in Tag) */
+    ID3Tag_LinkWithFlags(id3_tag,filename,ID3TT_ID3V2);
+
+    /*ID3_STRUCT(Mp3_Headerinfo)
+    {
+      Mpeg_Layers layer;
+      Mpeg_Version version;
+      MP3_BitRates bitrate;
+      Mp3_ChannelMode channelmode;
+      Mp3_ModeExt modeext;
+      Mp3_Emphasis emphasis;
+      Mp3_Crc crc;
+      uint32 vbr_bitrate;           // avg bitrate from xing header
+      uint32 frequency;             // samplerate
+      uint32 framesize;
+      uint32 frames;                // nr of frames
+      uint32 time;                  // nr of seconds in song
+      bool privatebit;
+      bool copyrighted;
+      bool original;
+    };*/
+
+    if ( (headerInfo = ID3Tag_GetMp3HeaderInfo(id3_tag)) )
+    {
+        switch (headerInfo->version)
+        {
+            case MPEGVERSION_1:
+                ETFileInfo->version = 1;
+                ETFileInfo->mpeg25 = FALSE;
+                break;
+            case MPEGVERSION_2:
+                ETFileInfo->version = 2;
+                ETFileInfo->mpeg25 = FALSE;
+                break;
+            case MPEGVERSION_2_5:
+                ETFileInfo->mpeg25 = TRUE;
+                ETFileInfo->mpeg25 = FALSE;
+                break;
+            default:
+                break;
+        }
+
+        switch (headerInfo->layer)
+        {
+            case MPEGLAYER_I:
+                ETFileInfo->layer = 1;
+                break;
+            case MPEGLAYER_II:
+                ETFileInfo->layer = 2;
+                break;
+            case MPEGLAYER_III:
+                ETFileInfo->layer = 3;
+                break;
+            default:
+                break;
+        }
+
+        // Samplerate
+        ETFileInfo->samplerate = headerInfo->frequency;
+
+        // Mode -> Seems to be detected but incorrect?!
+        switch (headerInfo->modeext)
+        {
+            case MP3CHANNELMODE_STEREO:
+                ETFileInfo->mode = 0;
+                break;
+            case MP3CHANNELMODE_JOINT_STEREO:
+                ETFileInfo->mode = 1;
+                break;
+            case MP3CHANNELMODE_DUAL_CHANNEL:
+                ETFileInfo->mode = 2;
+                break;
+            case MP3CHANNELMODE_SINGLE_CHANNEL:
+                ETFileInfo->mode = 3;
+                break;
+            default:
+                break;
+        }
+
+        // Bitrate
+        if (headerInfo->vbr_bitrate <= 0)
+        {
+            ETFileInfo->variable_bitrate = FALSE;
+            ETFileInfo->bitrate = headerInfo->bitrate/1000;
+        }else
+        {
+            ETFileInfo->variable_bitrate = TRUE;
+            ETFileInfo->bitrate = headerInfo->vbr_bitrate/1000;
+        }
+        
+        // Duration
+        ETFileInfo->duration = headerInfo->time;
+    }
+    
+    /* Free allocated data */
+    ID3Tag_Delete(id3_tag);
+    
+#endif
+
     return TRUE;
 }
 
