@@ -44,9 +44,9 @@ void        check_button_toggled (GtkCheckButton *checkbutton, gpointer data);
 static GtkDialogClass *parent_klass = NULL;
 
 
-guint msg_box_get_type(void)
+GType msg_box_get_type(void)
 {
-    static guint mb_type = 0;
+    static GType mb_type = 0;
 
     if (!mb_type)
     {
@@ -145,24 +145,27 @@ GtkWidget *msg_box_new (gchar *title, gchar *message, const gchar *stock_id,
         gtk_window_set_position(GTK_WINDOW(mb),GTK_WIN_POS_CENTER);
     else if (MESSAGE_BOX_POSITION_MOUSE)
         gtk_window_set_position(GTK_WINDOW(mb),GTK_WIN_POS_MOUSE);
+    else if (MESSAGE_BOX_POSITION_CENTER_ON_PARENT)
+        gtk_window_set_position(GTK_WINDOW(mb),GTK_WIN_POS_CENTER_ON_PARENT);
+
 
     /* Table to put: the pixmap, the message and the check button */
     Table = gtk_table_new(2,2,FALSE);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(mb)->vbox),Table,TRUE,TRUE,0);
-    gtk_container_set_border_width(GTK_CONTAINER(Table),5);
+    gtk_container_set_border_width(GTK_CONTAINER(Table),4);
     gtk_widget_show(Table);
 
     /* The Pixmap */
     Pixmap = gtk_image_new_from_stock(stock_id, GTK_ICON_SIZE_DIALOG);
     gtk_table_attach_defaults(GTK_TABLE(Table),Pixmap,0,1,0,1);
     //gtk_table_attach(GTK_TABLE(Table),Pixmap,0,1,0,1,GTK_FILL,GTK_FILL,0,0);
-    gtk_misc_set_padding(GTK_MISC(Pixmap),15,15);
+    gtk_misc_set_padding(GTK_MISC(Pixmap),6,6);
     gtk_widget_show(Pixmap);
 
     /* The Message */
     Label = gtk_label_new (message);
     gtk_table_attach_defaults(GTK_TABLE(Table),Label,1,2,0,1);
-    gtk_misc_set_padding(GTK_MISC(Label),5,10);
+    gtk_misc_set_padding(GTK_MISC(Label),6,6);
     gtk_label_set_justify(GTK_LABEL(Label),GTK_JUSTIFY_CENTER);
     //gtk_label_set_line_wrap(GTK_LABEL(Label),TRUE);
     gtk_widget_show(Label);
@@ -170,8 +173,7 @@ GtkWidget *msg_box_new (gchar *title, gchar *message, const gchar *stock_id,
     /* The Check Button */
     gtk_table_attach_defaults(GTK_TABLE(Table),mb->check_button,0,2,1,2);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(mb->check_button),mb->check_button_state);
-    g_signal_connect(G_OBJECT(mb->check_button),"toggled",
-        G_CALLBACK(check_button_toggled),mb);
+    g_signal_connect(G_OBJECT(mb->check_button),"toggled",G_CALLBACK(check_button_toggled),mb);
     gtk_widget_show(mb->check_button);
 
 
@@ -190,7 +192,7 @@ GtkWidget *msg_box_new (gchar *title, gchar *message, const gchar *stock_id,
         GTK_WIDGET_SET_FLAGS(Button,GTK_CAN_DEFAULT);
         g_signal_connect(G_OBJECT(Button),"destroy", G_CALLBACK(gtk_widget_destroyed),&Button);
         g_signal_connect(G_OBJECT(Button),"clicked", G_CALLBACK(msg_box_button_clicked),mb);
-        g_object_set_data(G_OBJECT(Button), "button_value", GINT_TO_POINTER(cursor_value));
+        g_object_set_data(G_OBJECT(Button),"button_value", GINT_TO_POINTER(cursor_value));
     }
     va_end(cursor);
     gtk_widget_grab_default(Button);
