@@ -85,7 +85,7 @@ enum Message_Type
 };
 
 
-guint msg_box_get_type(void);
+GType msg_box_get_type(void);
 
 GtkWidget *msg_box_new (gchar *title, gchar *message, const gchar *icon, ...);
 gint       msg_box_run (MsgBox *msgbox);
