@@ -53,28 +53,39 @@
 #define MULTIFIELD_SEPARATOR " - "
 
 /* Ogg Vorbis fields names in UTF-8 : http://www.xiph.org/vorbis/doc/v-comment.html
+ * 
+ * Field names :
  *
- * ALBUM       : if appropriate, an album name
- * ARTIST      : for information to be displayed on systems with limited display capabilities. it is not a replacement for the ENSEMBLE and PERFORMER tags, but typically will summarize them.
- * PUBLISHER   : who publishes the disc the track came from
- * COPYRIGHT   : who holds copyright to the track or disc the track is on
- * DISCNUMBER  : if part of a multi-disc album, put the disc number here
- * ISRC        : this number lets you order a CD over the phone from a record shop.
- * EAN/UPN     : there may be a barcode on the CD; it is most likely an EAN or UPN (Universal Product Number).
- * LABEL       : the record label or imprint on the disc
- * LABELNO     : record labels often put the catalog number of the source media somewhere on the packaging. use this tag to record it.
- * LICENSE     : the license, or URL for the license the track is under. for instance, the Open Audio license.
- * OPUS        : the number of the work; eg, Opus 10, BVW 81, K6
- * SOURCEMEDIA : the recording media the track came from. eg, CD, Cassette, Radio Broadcast, LP, CD Single
- * TITLE       : "the work", whether a symphony, or a pop song
- * TRACKNUMBER : the track number on the CD
- * TRACKTOTAL  : 
- * VERSION     : Make sure you don't put DATE or LOCATION information in this tag. "live", "acoustic", "Radio Edit" "12 inch remix" might be typical values of this tag
- * ENCODED-BY  : The person who encoded the Ogg file. May include contact information such as email address and phone number.
- * ENCODING    : Put the settings you used to encode the Ogg file here. This tag is NOT expected to be stored or returned by cddb type databases. It includes information about the quality setting, bit rate, and bitrate management settings used to encode the Ogg. It also is used for information about which encoding software was used to do the encoding.
+ * Below is a proposed, minimal list of standard field names with a description of intended use. No single or group of field names is mandatory; a comment header may contain one, all or none of the names in this list.
+ *
+ * TITLE        : Track/Work name
+ * VERSION      : The version field may be used to differentiate multiple versions of the same track title in a single collection. (e.g. remix info)
+ * ALBUM        : The collection name to which this track belongs
+ * TRACKNUMBER  : The track number of this piece if part of a specific larger collection or album
+ * ARTIST       : The artist generally considered responsible for the work. In popular music this is usually the performing band or singer. For classical music it would be the composer. For an audio book it would be the author of the original text.
+ * PERFORMER    : The artist(s) who performed the work. In classical music this would be the conductor, orchestra, soloists. In an audio book it would be the actor who did the reading. In popular music this is typically the same as the ARTIST and is omitted.
+ * COPYRIGHT    : Copyright attribution, e.g., '2001 Nobody's Band' or '1999 Jack Moffitt'
+ * LICENSE      : License information, eg, 'All Rights Reserved', 'Any Use Permitted', a URL to a license such as a Creative Commons license ("www.creativecommons.org/blahblah/license.html") or the EFF Open Audio License ('distributed under the terms of the Open Audio License. see http://www.eff.org/IP/Open_licenses/eff_oal.html for details'), etc.
+ * ORGANIZATION : Name of the organization producing the track (i.e. the 'record label')
+ * DESCRIPTION  : A short text description of the contents
+ * GENRE        : A short text indication of music genre
+ * DATE         : Date the track was recorded
+ * LOCATION     : Location where track was recorded
+ * CONTACT      : Contact information for the creators or distributors of the track. This could be a URL, an email address, the physical address of the producing label.
+ * ISRC         : ISRC number for the track; see the ISRC intro page for more information on ISRC numbers. 
  * 
  * The remaining tags are multiples; if they are present more than once, all their occurances are considered significant.
  * 
+ * PUBLISHER   : who publishes the disc the track came from
+ * DISCNUMBER  : if part of a multi-disc album, put the disc number here
+ * EAN/UPN     : there may be a barcode on the CD; it is most likely an EAN or UPN (Universal Product Number).
+ * LABEL       : the record label or imprint on the disc
+ * LABELNO     : record labels often put the catalog number of the source media somewhere on the packaging. use this tag to record it.
+ * OPUS        : the number of the work; eg, Opus 10, BVW 81, K6
+ * SOURCEMEDIA : the recording media the track came from. eg, CD, Cassette, Radio Broadcast, LP, CD Single
+ * TRACKTOTAL  : 
+ * ENCODED-BY  : The person who encoded the Ogg file. May include contact information such as email address and phone number.
+ * ENCODING    : Put the settings you used to encode the Ogg file here. This tag is NOT expected to be stored or returned by cddb type databases. It includes information about the quality setting, bit rate, and bitrate management settings used to encode the Ogg. It also is used for information about which encoding software was used to do the encoding.
  * COMPOSER    : composer of the work. eg, Gustav Mahler
  * ARRANGER    : the person who arranged the piece, eg, Ravel
  * LYRICIST    : the person who wrote the lyrics, eg Donizetti
@@ -84,8 +95,6 @@
  * ENSEMBLE    : the group playing the piece, whether orchestra, singing duo, or rock and roll band.
  * PART        : a division within a work; eg, a movement of a symphony. Some tracks contain several parts. Use a single PART tag for each part contained in a track. ie, PART="Oh sole mio"
  * PARTNUMBER  : The part number goes in here. You can use any format you like, such as Roman numerals, regular numbers, or whatever. The numbers should be entered in such a way that an alphabetical sort on this tag will correctly show the proper ordering of all the oggs that contain the contain the piece of music.
- * GENRE       : like the genre tag from the cddb but without the limitations. You can put any genre you want in this tag. If you think "Pink Floyd" are a genre unto themselves, say so here. For crossover works, or ambiguous works, use as many GENRE tags as you think it takes to describe the styles used.
- * DATE        : date or date-time of relevance to the track. The date must be in ISO 8601 format, but may be followed by a space character, then any text you wish, including the same date in any other format. None of the alternate formats in ISO 8601 may be used. Only the primary format in ISO 8601 is to be used. q.v. http://www.cl.cam.ac.uk/~mgk25/iso-time.html eg, DATE="1999-08-16 (recorded)" or DATE="1999-08-16 recorded August 16, 1999"
  * LOCATION    : location of recording, or other location of interest
  * COMMENT     : additional comments of any nature.
  */
@@ -114,6 +123,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     vorbis_comment *vc;
     gchar          *string = NULL;
     gchar          *string1 = NULL;
+    gchar          *string2 = NULL;
     gchar          *filename_utf8 = filename_to_display(filename);
     guint           field_num, i;
 
@@ -292,15 +302,28 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
      ***********/
     field_num = 0;
     string1 = NULL; // Cause it may be not updated into the 'while' condition
-    while ( ((string  = vorbis_comment_query(vc,"COMMENT",field_num)) != NULL )   // Winamp format
-         || ((string1 = vorbis_comment_query(vc,"",       field_num)) != NULL ) ) // Xmms format
+    while ( ((string2 = vorbis_comment_query(vc,"DESCRIPTION",field_num)) != NULL )   // New specifications
+         || ((string  = vorbis_comment_query(vc,"COMMENT",    field_num)) != NULL )   // Old : Winamp format (for EasyTAG 1.99.11 and older)
+         || ((string1 = vorbis_comment_query(vc,"",           field_num)) != NULL ) ) // Old : Xmms format   (for EasyTAG 1.99.11 and older)
     {
-        if ( string && g_utf8_strlen(string, -1) > 0 ) // Contains comment to Winamp format and we prefer this format (field name defined)
+        if ( string2 && g_utf8_strlen(string2, -1) > 0 ) // Contains comment to new specifications format and we prefer this format (field name defined)
+        {
+            if (FileTag->comment==NULL)
+                FileTag->comment = g_strdup(string2);
+            else
+                FileTag->comment = g_strconcat(FileTag->comment,MULTIFIELD_SEPARATOR,string2,NULL);
+            // Frees allocated data
+            if (string && g_utf8_strlen(string, -1) > 0)
+                g_free(string);
+            if (string1 && g_utf8_strlen(string1, -1) > 0)
+                g_free(string1);
+        }else if ( string && g_utf8_strlen(string, -1) > 0 ) // Contains comment to Winamp format and we prefer this format (field name defined)
         {
             if (FileTag->comment==NULL)
                 FileTag->comment = g_strdup(string);
             else
                 FileTag->comment = g_strconcat(FileTag->comment,MULTIFIELD_SEPARATOR,string,NULL);
+            // Frees allocated data
             if (string1 && g_utf8_strlen(string1, -1) > 0)
                 g_free(string1);
         }else if ( string1 && g_utf8_strlen(string1, -1) > 0 ) // Contains comment to Xmms format only
@@ -310,6 +333,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             else
                 FileTag->comment = g_strconcat(FileTag->comment,MULTIFIELD_SEPARATOR,string1,NULL);
         }
+        string  = NULL;
         string1 = NULL;
         field_num++;
     }
@@ -403,6 +427,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
           && strncasecmp(vc->user_comments[i],"TRACKNUMBER=",12) != 0
           && strncasecmp(vc->user_comments[i],"TRACKTOTAL=", 11) != 0
           && strncasecmp(vc->user_comments[i],"GENRE=",       6) != 0
+          && strncasecmp(vc->user_comments[i],"DESCRIPTION=",12) != 0
           && strncasecmp(vc->user_comments[i],"COMMENT=",     8) != 0
           && strncasecmp(vc->user_comments[i],"=",            1) != 0
           && strncasecmp(vc->user_comments[i],"COMPOSER=",    9) != 0
@@ -579,9 +604,14 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
     /***********
      * Comment *
      ***********/
-    // We write the comment using the "both" format
+    // We write the comment using the two formats "DESCRIPTION" and "COMMENT" to be compatible with old versions
     if ( FileTag->comment )
     {
+        // Format of new specification
+        string = g_strconcat("DESCRIPTION=",FileTag->comment,NULL);
+        vorbis_comment_add(vc,string);
+        g_free(string);
+
         // Format used in winamp plugin
         string = g_strconcat("COMMENT=",FileTag->comment,NULL);
         vorbis_comment_add(vc,string);
@@ -590,7 +620,7 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
         if (OGG_TAG_WRITE_XMMS_COMMENT)
         {
             // Format used into xmms-1.2.5
-            string  = g_strconcat("=",FileTag->comment,NULL);
+            string = g_strconcat("=",FileTag->comment,NULL);
             vorbis_comment_add(vc,string);
             g_free(string);
         }
@@ -662,8 +692,8 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
     /* Write tag */
     if ( Ogg_Tag_Write_File(file_in,filename,state) == FALSE )
     {
-        g_print(_("ERROR: Failed to write comments to file '%s' (%s).\n"),filename_utf8,vcedit_error(state));
         ogg_error_msg = vcedit_error(state);
+        g_print(_("ERROR: Failed to write comments to file '%s' (%s).\n"),filename_utf8,ogg_error_msg == NULL ? "" : ogg_error_msg);
         g_free(filename_utf8);
         return FALSE;
     }else
@@ -721,6 +751,15 @@ gboolean Ogg_Tag_Write_File (FILE *file_in, gchar *filename_in, vcedit_state *st
     if (fclose(file_out) != 0)
         return_code = FALSE;
 
+    // TIX ME : Part commented as the ogg file will be corrupted later...
+//#ifdef WIN32
+//    // Under Win32, rename(a,b) fails if b exists...
+//    if(return_code == TRUE)
+//    {
+//        remove(filename_in);
+//    }
+//#endif
+
     if ( (return_code==FALSE) || (rename(filename_tmp,filename_in)<0) )
     {
         remove(filename_tmp);
