@@ -69,10 +69,6 @@ void Cddb_Use_Proxy_Toggled                    (void);
 
 void DefaultPathToMp3_Combo_Add_String (void);
 
-/* Browser */
-static void Open_File_Selection_Window (GtkWidget *entry, gchar *title, GtkFileChooserAction action);
-void        File_Selection_Window_For_File      (GtkWidget *entry);
-void        File_Selection_Window_For_Directory (GtkWidget *entry);
 
 
 /*************
@@ -101,6 +97,7 @@ void Open_OptionsWindow (void)
     GtkTooltips *Tips;
     gchar temp[MAX_STRING_LEN];
     gchar *path_utf8;
+    gchar *program_path;
 
     /* Check if already opened */
     if (OptionsWindow)
@@ -405,8 +402,9 @@ void Open_OptionsWindow (void)
     Load_Audio_File_Player_List(FilePlayerModel, MISC_COMBO_TEXT);
     Add_String_To_Combo_List(FilePlayerModel, AUDIO_FILE_PLAYER);
     // Don't load the parameter if XMMS not found, else user can't save the preference
-    if (Check_If_Executable_Exists(AUDIO_FILE_PLAYER))
+    if ( (program_path=Check_If_Executable_Exists(AUDIO_FILE_PLAYER)))
         gtk_entry_set_text(GTK_ENTRY(GTK_BIN(FilePlayerCombo)->child), AUDIO_FILE_PLAYER);
+    g_free(program_path);
 
     // Button browse
     Button = Create_Button_With_Pixmap(BUTTON_BROWSE);
@@ -1503,11 +1501,14 @@ gint Check_DefaultComment (void)
  */
 gint Check_FilePlayerCombo (void)
 {
+    gchar *program_path;
+    
 #ifdef WIN32
     return 1; /* FIXME see Check_If_Executable_Exists */
+    /* Note : Check_If_Executable_Exists crashes when player is 'winamp.exe' with g_find_program_in_path */
 #endif
 
-    if ( !Check_If_Executable_Exists( gtk_entry_get_text(GTK_ENTRY(GTK_BIN(FilePlayerCombo)->child)) ) )
+    if ( !(program_path = Check_If_Executable_Exists( gtk_entry_get_text(GTK_ENTRY(GTK_BIN(FilePlayerCombo)->child)) ) ) )
     {
         gchar *msg = g_strdup_printf(_("The audio file player '%s' can't be found!"),
             gtk_entry_get_text(GTK_ENTRY(GTK_BIN(FilePlayerCombo)->child)));
@@ -1521,6 +1522,7 @@ gint Check_FilePlayerCombo (void)
         return 0;
     } else
     {
+        g_free(program_path);
         return 1;
     }
 }
@@ -1538,59 +1540,6 @@ gint Check_Config (void)
 
 
 
-void File_Selection_Window_For_File (GtkWidget *entry)
-{
-    Open_File_Selection_Window(entry, _("Select directory..."), GTK_FILE_CHOOSER_ACTION_OPEN);
-}
-
-void File_Selection_Window_For_Directory (GtkWidget *entry)
-{
-    Open_File_Selection_Window(entry, _("Select file..."), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
-}
-
-/*
- * Open the file selection window and saves the selected file path into entry
- */
-static void Open_File_Selection_Window (GtkWidget *entry, gchar *title, GtkFileChooserAction action)
-{
-    gchar *tmp;
-    gchar *filename, *filename_utf8;
-    GtkWidget *FileSelectionWindow;
-    GtkWindow *parent_window = NULL;
-
-    parent_window = (GtkWindow*) gtk_widget_get_toplevel(entry);
-    if (!GTK_WIDGET_TOPLEVEL(parent_window))
-    {
-        g_warning("Could not get parent window\n");
-        return;
-    }
-
-    FileSelectionWindow = gtk_file_chooser_dialog_new(title, parent_window, action,
-                                                      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                                      GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-                                                      NULL);
-    // Set initial directory
-    tmp = (gchar*) gtk_entry_get_text(GTK_ENTRY(entry));
-    if (tmp && *tmp)
-    {
-        if (!gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(FileSelectionWindow),tmp))
-            gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(FileSelectionWindow),tmp);
-    }
-
-
-    if (gtk_dialog_run(GTK_DIALOG(FileSelectionWindow)) == GTK_RESPONSE_ACCEPT)
-    {
-        filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(FileSelectionWindow));
-        filename_utf8 = filename_to_display(filename);
-        gtk_entry_set_text(GTK_ENTRY(entry),filename_utf8);
-        g_free(filename);
-        g_free(filename_utf8);
-    }
-    gtk_widget_destroy(FileSelectionWindow);
-}
-
-
-
 /*
  * Manage Check buttons into Scanner tab: conversion group
  * This reproduces "something" like the behaviour of radio buttons with check buttons
