@@ -57,7 +57,7 @@
  *    NetBSD's mkdir(2).
  */
 
-// Base directory created into home dir 
+// Base directory created into home dir
 gchar *EASYTAG_DIR                                 = ".easytag";
 // File for configuration
 gchar *CONFIG_FILE                                 = ".easytag/easytagrc";
@@ -437,7 +437,7 @@ void Init_Config_Variables (void)
     PROCESS_COPYRIGHT_FIELD            = 1;
     PROCESS_URL_FIELD                  = 1;
     PROCESS_ENCODED_BY_FIELD           = 1;
-    
+
     PF_CONVERT_INTO_SPACE              = 1;
     PF_CONVERT_SPACE                   = 0;
     PF_CONVERT                         = 0;
@@ -542,14 +542,14 @@ void Init_Config_Variables (void)
     RENAME_FILE_DEFAULT_MASK        = NULL;
     RENAME_DIRECTORY_DEFAULT_MASK   = NULL;
     RENAME_DIRECTORY_WITH_MASK      = 0;
-    
+
     /*
      * Other parameters
      */
     OPTIONS_NOTEBOOK_PAGE = 0;
     OPTIONS_WINDOW_HEIGHT = 300;
     OPTIONS_WINDOW_WIDTH  = 400;
-    
+
 }
 
 
@@ -569,9 +569,9 @@ void Apply_Changes_Of_Preferences_Window (void)
         LOAD_ON_STARTUP               = GTK_TOGGLE_BUTTON(LoadOnStartup)->active;
         if (DEFAULT_PATH_TO_MP3) g_free(DEFAULT_PATH_TO_MP3);
         DEFAULT_PATH_TO_MP3           = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_BIN(DefaultPathToMp3)->child))); // Saved in UTF-8
-#ifdef WIN32
-        ET_Win32_Path_Replace_Backslashes(DEFAULT_PATH_TO_MP3);
-#endif
+//#ifdef WIN32
+//        ET_Win32_Path_Replace_Backslashes(DEFAULT_PATH_TO_MP3);
+//#endif
         BROWSE_SUBDIR                 = GTK_TOGGLE_BUTTON(BrowseSubdir)->active;
         BROWSE_HIDDEN_DIR             = GTK_TOGGLE_BUTTON(BrowseHiddendir)->active;
         OPEN_SELECTED_BROWSER_NODE    = GTK_TOGGLE_BUTTON(OpenSelectedBrowserNode)->active;
@@ -624,7 +624,7 @@ void Apply_Changes_Of_Preferences_Window (void)
         USE_ID3V2_PADDING             = GTK_TOGGLE_BUTTON(UseId3v2Padding)->active;
         STRIP_TAG_WHEN_EMPTY_FIELDS   = GTK_TOGGLE_BUTTON(StripTagWhenEmptyFields)->active;
         CONVERT_OLD_ID3V2_TAG_VERSION = GTK_TOGGLE_BUTTON(ConvertOldId3v2TagVersion)->active;
-        
+
         USE_ID3_ISO_8859_1_CHARACTER_SET                = GTK_TOGGLE_BUTTON(UseId3ISO88591CharacterSet)->active;
         USE_ID3_ISO_8859_1_THEN_UNICODE_CHARACTER_SET   = GTK_TOGGLE_BUTTON(UseId3ISO88591ThenUnicodeCharacterSet)->active;
         USE_ID3_UNICODE_CHARACTER_SET                   = GTK_TOGGLE_BUTTON(UseId3UnicodeCharacterSet)->active;
@@ -677,7 +677,7 @@ void Apply_Changes_Of_Preferences_Window (void)
         CDDB_PROXY_USER_NAME          = g_strdup(gtk_entry_get_text(GTK_ENTRY(CddbProxyUserName)));
         if (CDDB_PROXY_USER_PASSWORD) g_free(CDDB_PROXY_USER_PASSWORD);
         CDDB_PROXY_USER_PASSWORD      = g_strdup(gtk_entry_get_text(GTK_ENTRY(CddbProxyUserPassword)));
-        
+
         CDDB_FOLLOW_FILE    = GTK_TOGGLE_BUTTON(CddbFollowFile)->active;
         CDDB_USE_DLM        = GTK_TOGGLE_BUTTON(CddbUseDLM)->active;
 
@@ -708,7 +708,7 @@ void Apply_Changes_Of_Preferences_Window (void)
 
         /* Reload if number of character changed for track list */
         //Load_Track_List_To_UI();
-        
+
         /* Reload directory, in case we have changed BROWSE_HIDDEN_DIR */
         // FIX ME : commented as it reloads files...
         //Browser_Tree_Rebuild(NULL);
@@ -743,7 +743,7 @@ void Apply_Changes_Of_UI (void)
 
     // Configuration of the scanner window (see scan.c) - Function also called when destroying the window
     ScannerWindow_Apply_Changes();
-    
+
     // Configuration of the cddb window (see cddb.c) - Function also called when destroying the window
     Cddb_Window_Apply_Changes();
 
@@ -785,7 +785,7 @@ void Save_Config_To_File (void)
     /* The file to write */
     if (!HOME_VARIABLE) return;
     file_path = g_strconcat(HOME_VARIABLE,
-                            HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!='/'?"/":"",
+                            HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!=G_DIR_SEPARATOR?G_DIR_SEPARATOR_S:"",
                             CONFIG_FILE,NULL);
 
     if ( Create_Easytag_Directory()==0 || (file=fopen(file_path,"w+"))==0 )
@@ -848,7 +848,7 @@ void Save_Config_To_File (void)
 
 
 /*
- * Parse lines read (line as <var_description>=<value>) and load the values 
+ * Parse lines read (line as <var_description>=<value>) and load the values
  * into the corresponding config variables.
  */
 void Set_Config (gchar *line)
@@ -868,15 +868,17 @@ void Set_Config (gchar *line)
     ConfigVarListLen = sizeof(Config_Variables)/sizeof(tConfigVariable);
     for (i=0; i<ConfigVarListLen; i++)
     {
-        if (!strcmp(Config_Variables[i].name,var_descriptor))
+        if (Config_Variables[i].name!=NULL && var_descriptor
+        && !strcmp(Config_Variables[i].name,var_descriptor))
         {
-            switch(Config_Variables[i].type)
+            switch (Config_Variables[i].type)
             {
                 case CV_TYPE_INT:
                 {
                     *(int *)Config_Variables[i].pointer = strtol(var_value, NULL, 10);
                     break;
                 }
+
                 case CV_TYPE_BOOL:
                 {
                     if (strtol(var_value, NULL, 10))
@@ -885,6 +887,7 @@ void Set_Config (gchar *line)
                         *(int *)Config_Variables[i].pointer = 0;
                     break;
                 }
+
                 case CV_TYPE_STRING:
                 {
                     if (!var_value)
@@ -900,6 +903,7 @@ void Set_Config (gchar *line)
                     }
                     break;
                 }
+
                 default:
                 {
                     g_print("ERROR: Can't read: type of config variable not supported "
@@ -924,7 +928,7 @@ void Read_Config (void)
     /* The file to read */
     if (!HOME_VARIABLE) return;
     file_path = g_strconcat(HOME_VARIABLE,
-                            HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!='/'?"/":"",
+                            HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!=G_DIR_SEPARATOR?G_DIR_SEPARATOR_S:"",
                             CONFIG_FILE,NULL);
 
     if ( (file=fopen(file_path,"r"))==0 )
@@ -933,7 +937,7 @@ void Read_Config (void)
         g_print(_("Loading default configuration...\n"));
     }else
     {
-        while(fgets(buffer,sizeof(buffer),file))
+        while (fgets(buffer,sizeof(buffer),file))
         {
             if (buffer[strlen(buffer)-1]=='\n')
                 buffer[strlen(buffer)-1]='\0';
@@ -961,7 +965,7 @@ void Display_Config (void)
     /* The file to write */
     if (!HOME_VARIABLE) return;
     file_path = g_strconcat(HOME_VARIABLE,
-                            HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!='/'?"/":"",
+                            HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!=G_DIR_SEPARATOR?G_DIR_SEPARATOR_S:"",
                             CONFIG_FILE,NULL);
 
     if ( (file=fopen(file_path,"r"))==0 )
@@ -1023,7 +1027,7 @@ gboolean Setting_Create_Files (void)
         return FALSE;
 
     home_path = g_strconcat(HOME_VARIABLE,
-                            HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!='/'?"/":"",
+                            HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!=G_DIR_SEPARATOR?G_DIR_SEPARATOR_S:"",
                             NULL);
 
     file_path = g_strconcat(home_path,CONFIG_FILE,NULL);
@@ -1162,7 +1166,7 @@ void Save_List_Store_To_File (gchar *filename, GtkListStore *liststore, gint col
     /* The file to write */
     if (!HOME_VARIABLE) return;
     file_path = g_strconcat(HOME_VARIABLE,
-                            HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!='/'?"/":"",
+                            HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!=G_DIR_SEPARATOR?G_DIR_SEPARATOR_S:"",
                             filename,NULL);
 
     if ( Create_Easytag_Directory()==0 || (file=fopen(file_path,"w+"))==NULL )
@@ -1176,7 +1180,7 @@ void Save_List_Store_To_File (gchar *filename, GtkListStore *liststore, gint col
             data = g_strdup_printf("%s\n",text);
             g_free(text);
 
-            if (data) 
+            if (data)
             {
                 fwrite(data,strlen(data),1,file);
                 g_free(data);
@@ -1202,7 +1206,7 @@ gboolean Populate_List_Store_From_File (gchar *filename, GtkListStore *liststore
     /* The file to write */
     if (!filename || !HOME_VARIABLE) return FALSE;
     file_path = g_strconcat(HOME_VARIABLE,
-                            HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!='/'?"/":"",
+                            HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!=G_DIR_SEPARATOR?G_DIR_SEPARATOR_S:"",
                             filename,NULL);
 
     if ( (file=fopen(file_path,"r"))==NULL )
@@ -1488,9 +1492,9 @@ gboolean Create_Easytag_Directory (void)
     /* Directory to create (if doesn't exists) with absolute path
      * Note for NetBSD : avoid passing a trailing slash to mkdir() */
     easytag_path = g_strconcat(HOME_VARIABLE,
-                               HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!='/'?"/":"",
+                               HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!=G_DIR_SEPARATOR?G_DIR_SEPARATOR_S:"",
                                EASYTAG_DIR,
-                               //EASYTAG_DIR[strlen(EASYTAG_DIR)-1]!='/'?"/":"",
+                               //EASYTAG_DIR[strlen(EASYTAG_DIR)-1]!=G_DIR_SEPARATOR?G_DIR_SEPARATOR_S:"",
                                NULL);
 
     if ( (dir=opendir(easytag_path)) == NULL )
@@ -1498,7 +1502,7 @@ gboolean Create_Easytag_Directory (void)
         if ( (mkdir(easytag_path,S_IRWXU|S_IXGRP|S_IRGRP)) == -1)
         {
             g_print(_("ERROR: Can't create directory '%s' (%s)!\n"),easytag_path,g_strerror(errno));
-            return FALSE;          
+            return FALSE;
         }
     }else
     {
