@@ -257,7 +257,9 @@ gint    RENAME_DIRECTORY_WITH_MASK;
 
 
 /* Other parameters */
-gint     OPTIONS_NOTEBOOK_PAGE;
+gint    OPTIONS_NOTEBOOK_PAGE;
+gint    OPTIONS_WINDOW_HEIGHT;
+gint    OPTIONS_WINDOW_WIDTH;
 
 
 
