@@ -310,7 +310,7 @@ void str_replace_char (gchar *str, gchar in_char, gchar out_char)
 
 
 
-/* remove trailing '/' if any */
+/* Remove trailing '/' if any */
 void ET_Win32_Path_Remove_Trailing_Slash (gchar *path)
 {
     int path_len = strlen(path);
@@ -321,6 +321,17 @@ void ET_Win32_Path_Remove_Trailing_Slash (gchar *path)
     }
 }
 
+/* Remove trailing '\' if any */
+void ET_Win32_Path_Remove_Trailing_Backslash (gchar *path)
+{
+    int path_len = strlen(path);
+  
+    if(path_len > 3 && path[path_len - 1] == '\\')
+    {
+        path[path_len - 1] = '\0';
+    }
+}
+
 void ET_Win32_Path_Replace_Backslashes (gchar *path)
 {
     str_replace_char(path, '\\', '/');
@@ -395,7 +406,7 @@ void ET_Win32_Init (HINSTANCE hint)
         g_strlcpy(app_data_dir, newenv, sizeof(app_data_dir));
     }
 
-    ET_Win32_Path_Replace_Backslashes(app_data_dir);
+    //ET_Win32_Path_Replace_Backslashes(app_data_dir);
 
     g_print("HOME dir for settings: %s\n", app_data_dir);
 
